%define anolis_release 3

%global debug_package %{nil}

Name:    arm-trusted-firmware
Version: 2.8
Release: %{anolis_release}%{dist}
Summary: ARM Trusted Firmware
License: BSD
URL:     https://github.com/ARM-software/arm-trusted-firmware
Source0: https://github.com/ARM-software/arm-trusted-firmware/archive/refs/tags/v%{version}.tar.gz
Source1: aarch64-bl31
Patch0001:  0001-atf-2.8-fix-linking.patch
# https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/commit/?id=fd37982a19a4a291
Patch0002:  CVE-2022-47630-1.patch
# https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/commit/?id=72460f50e2437a85
Patch0003:  CVE-2022-47630-2.patch
# https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/commit/?id=f5c51855d36e399e
Patch0004:  CVE-2022-47630-3.patch

ExclusiveArch: aarch64
BuildRequires: gcc dtc

%description
ARM Trusted firmware is a reference implementation of secure world software for
ARMv8-A including Exception Level 3 (EL3) software. It provides a number of
standard ARM interfaces like Power State Coordination (PSCI), Trusted Board
Boot Requirements (TBBR) and Secure Monitor.

Note: the contents of this package are generally just consumed by bootloaders
such as u-boot. As such the binaries aren't of general interest to users.

%ifarch aarch64
%package     -n arm-trusted-firmware-armv8
Summary:     ARM Trusted Firmware for ARMv8-A

%description -n arm-trusted-firmware-armv8
ARM Trusted Firmware binaries for various  ARMv8-A SoCs.

Note: the contents of this package are generally just consumed by bootloaders
such as u-boot. As such the binaries aren't of general interest to users.
%endif

%package -n arm-trusted-firmware-armv8-doc
Summary:        Documentation files for %{name}
Requires:       arm-trusted-firmware-armv8 = %{EVR}
BuildArch:      noarch

%description -n arm-trusted-firmware-armv8-doc
The arm-trusted-firmware-armv8-doc package contains documentation files for arm-trusted-firmware-armv8.

%prep
%autosetup -n %{name}-%{version} -p1
cp %SOURCE1 .
sed -i 's/arm-none-eabi-/arm-linux-gnu-/' plat/rockchip/rk3399/drivers/m0/Makefile

%build
%undefine _auto_set_build_flags
%ifarch aarch64
for soc in $(cat %{_arch}-bl31)
do
# At the moment we're only making the secure firmware (bl31)
make HOSTCC="gcc $RPM_OPT_FLAGS -fPIE -Wl,-z,relro,-z,now" CROSS_COMPILE="" PLAT=$(echo $soc) bl31
done
%endif

%install

mkdir -p %{buildroot}%{_datadir}/%{name}

%ifarch aarch64
# At the moment we just support adding bl31.bin
for soc in $(cat %{_arch}-bl31)
do
mkdir -p %{buildroot}%{_datadir}/%{name}/$(echo $soc)/
 for file in bl31.bin
 do
  if [ -f build/$(echo $soc)/release/$(echo $file) ]; then
    install -p -m 0644 build/$(echo $soc)/release/$(echo $file) /%{buildroot}%{_datadir}/%{name}/$(echo $soc)/
  fi
 done
done

# Rockchips wants the bl31.elf, plus rk3399 wants power management co-processor bits
for soc in rk3399 rk3368 rk3328
do
mkdir -p %{buildroot}%{_datadir}/%{name}/$(echo $soc)/
 for file in bl31/bl31.elf m0/rk3399m0.bin m0/rk3399m0.elf
 do
  if [ -f build/$(echo $soc)/release/$(echo $file) ]; then
    install -p -m 0644 build/$(echo $soc)/release/$(echo $file) /%{buildroot}%{_datadir}/%{name}/$(echo $soc)/
  fi
 done
done

%endif

%generate_compatibility_deps

%ifarch aarch64
%files -n arm-trusted-firmware-armv8
%license license.rst
%{_datadir}/%{name}
%endif

%files -n arm-trusted-firmware-armv8-doc
%doc readme.rst

%changelog
* Wed Dec 04 2024 Zhongkun He <hezhongkun@inspur.com> - 2.8-3
- Fix CVE-2022-47630

* Mon Apr 17 2023 yuanhui <yuanhui@linux.alibaba.com> - 2.8-2
- Fix the bug for sun50i_a64 not found error

* Sat Apr 15 2023 yuanhui <yuanhui@linux.alibaba.com> - 2.8-1
- Init package from upstream

